@@ -8,7 +8,8 @@
 #' @param posterior posterior estimation outcome obtained by running the \code{estimate} function. 
 #' The interpretation depends on the normalisation of the shocks
 #' using function \code{normalise_posterior()}. Verify if the default settings are appropriate.
-#' @param horizon a positive integer number denoting the forecast horizon for the impulse responses computations.
+#' @param horizon a positive integer number denoting the forecast horizon for 
+#' the forecast error variance decomposition computations.
 #' 
 #' @return An object of class PosteriorFEVD, that is, an \code{NxNx(horizon+1)xS} array with attribute PosteriorFEVD 
 #' containing \code{S} draws of the forecast error variance decomposition.
@@ -71,11 +72,12 @@ compute_variance_decompositions.PosteriorBSVAR <- function(posterior, horizon) {
   N               = dim(posterior_A)[1]
   p               = posterior$last_draw$p
   S               = dim(posterior_A)[3]
-
+  Y               = posterior$last_draw$data_matrices$Y
+  
   posterior_irf   = .Call(`_bsvars_bsvars_ir`, posterior_B, posterior_A, horizon, p, TRUE)
   qqq             = .Call(`_bsvars_bsvars_fevd_homosk`, posterior_irf)
 
-  fevd            = array(NA, c(N, N, horizon + 1, S))
+  fevd            = array(NA, c(N, N, horizon + 1, S), dimnames = list(rownames(Y), rownames(Y), 0:horizon, 1:S))
   for (s in 1:S) fevd[,,,s] = qqq[s][[1]]
   class(fevd)     = "PosteriorFEVD"
 
@@ -135,12 +137,13 @@ compute_variance_decompositions.PosteriorBSVARMSH <- function(posterior, horizon
   posterior_sigma2 = posterior$posterior$sigma2
   S_T             = posterior$posterior$xi[,T,]
   sigma2_T        = posterior$posterior$sigma[,T,]^2
-  
+  Y               = posterior$last_draw$data_matrices$Y
+
   posterior_irf   = .Call(`_bsvars_bsvars_ir`, posterior_B, posterior_A, horizon, p, TRUE)
   sigma2          = .Call(`_bsvars_forecast_sigma2_msh`, posterior_sigma2, posterior_PR_TR, S_T, horizon)
   qqq             = .Call(`_bsvars_bsvars_fevd_heterosk`, posterior_irf, sigma2, sigma2_T)
   
-  fevd            = array(NA, c(N, N, horizon + 1, S))
+  fevd            = array(NA, c(N, N, horizon + 1, S), dimnames = list(rownames(Y), rownames(Y), 0:horizon, 1:S))
   for (s in 1:S) fevd[,,,s] = qqq[s][[1]]
   class(fevd)     = "PosteriorFEVD"
   
@@ -204,12 +207,13 @@ compute_variance_decompositions.PosteriorBSVARMIX <- function(posterior, horizon
   posterior_sigma2 = posterior$posterior$sigma2
   S_T             = posterior$posterior$xi[,T,]
   sigma2_T        = posterior$posterior$sigma[,T,]^2
-  
+  Y               = posterior$last_draw$data_matrices$Y
+
   posterior_irf   = .Call(`_bsvars_bsvars_ir`, posterior_B, posterior_A, horizon, p, TRUE)
   sigma2          = .Call(`_bsvars_forecast_sigma2_msh`, posterior_sigma2, posterior_PR_TR, S_T, horizon)
   qqq             = .Call(`_bsvars_bsvars_fevd_heterosk`, posterior_irf, sigma2, sigma2_T)
   
-  fevd            = array(NA, c(N, N, horizon + 1, S))
+  fevd            = array(NA, c(N, N, horizon + 1, S), dimnames = list(rownames(Y), rownames(Y), 0:horizon, 1:S))
   for (s in 1:S) fevd[,,,s] = qqq[s][[1]]
   class(fevd)     = "PosteriorFEVD"
   
@@ -268,12 +272,13 @@ compute_variance_decompositions.PosteriorBSVARSV <- function(posterior, horizon)
   posterior_omega = posterior$posterior$omega
   centred_sv      = posterior$last_draw$centred_sv
   sigma2_T        = posterior$posterior$sigma[,T,]^2
-  
+  Y               = posterior$last_draw$data_matrices$Y
+
   posterior_irf   = .Call(`_bsvars_bsvars_ir`, posterior_B, posterior_A, horizon, p, TRUE)
   sigma2          = .Call(`_bsvars_forecast_sigma2_sv`, posterior_h_T, posterior_rho, posterior_omega, horizon, centred_sv)
   qqq             = .Call(`_bsvars_bsvars_fevd_heterosk`, posterior_irf, sigma2, sigma2_T)
   
-  fevd            = array(NA, c(N, N, horizon + 1, S))
+  fevd            = array(NA, c(N, N, horizon + 1, S), dimnames = list(rownames(Y), rownames(Y), 0:horizon, 1:S))
   for (s in 1:S) fevd[,,,s] = qqq[s][[1]]
   class(fevd)     = "PosteriorFEVD"
   
@@ -329,7 +334,8 @@ compute_variance_decompositions.PosteriorBSVART <- function(posterior, horizon)
   T               = dim(posterior$posterior$lambda)[1]
   sigma2          = array(NA, c(N, horizon, S))
   sigma2_T        = matrix(NA, N, S)
-  
+  Y               = posterior$last_draw$data_matrices$Y
+
   posterior_irf   = .Call(`_bsvars_bsvars_ir`, posterior_B, posterior_A, horizon, p, TRUE)
   lambda          = .Call(`_bsvars_forecast_lambda_t`, posterior_df, horizon) # (horizon, S)
   for (n in 1:N) {
@@ -338,7 +344,7 @@ compute_variance_decompositions.PosteriorBSVART <- function(posterior, horizon)
   }
   qqq             = .Call(`_bsvars_bsvars_fevd_heterosk`, posterior_irf, sigma2, sigma2_T)
   
-  fevd            = array(NA, c(N, N, horizon + 1, S))
+  fevd            = array(NA, c(N, N, horizon + 1, S), dimnames = list(rownames(Y), rownames(Y), 0:horizon, 1:S))
   for (s in 1:S) fevd[,,,s] = qqq[s][[1]]
   class(fevd)     = "PosteriorFEVD"
   
